@@ -1,6 +1,6 @@
 package Benchmark::Perl::Formance;
 
-use 5.006001; # I don't really know yet, but that's the goal
+use 5.008;
 
 use warnings;
 use strict;
@@ -11,10 +11,11 @@ use Getopt::Long ":config", "no_ignore_case", "bundling";
 use Data::Structure::Util "unbless";
 use Data::YAML::Writer;
 use Time::HiRes qw(gettimeofday);
+use Devel::Platform::Info;
 
 use vars qw($VERSION @ISA @EXPORT_OK);
 
-$VERSION = '0.08';
+$VERSION = '0.09';
 
 push @ISA, 'Exporter'; @EXPORT_OK = qw(run print_results);
 
@@ -63,6 +64,8 @@ sub usage
 Usage:
 
    $ benchmark-perlformance
+   $ benchmark-perlformance --fast
+   $ benchmark-perlformance --useforks
    $ benchmark-perlformance --plugins=SpamAssassin,RegexpCommonTS,RxCmp -v
    $ benchmark-perlformance -ccccc --indent=2
    $ benchmark-perlformance -q
@@ -75,10 +78,6 @@ To use another perl start it via
 
    $ /other/path/to/bin/perl /path/to/benchmark-perlformance
 
-To provide environment variables (for some plugins) you can do
-
-   $ PERLFORMANCE_TESTMODE_FAST=1 benchmark-perlformance
-
 For more details see
 
    man benchmark-perlformance
@@ -92,12 +91,16 @@ sub run {
 
         my $help           = 0;
         my $showconfig     = 0;
+        my $platforminfo   = 0;
         my $verbose        = 0;
+        my $fastmode       = 0;
+        my $useforks       = 0;
         my $quiet          = 0;
         my $options        = {};
         my $plugins        = $DEFAULT_PLUGINS;
         my $indent         = $DEFAULT_INDENT;
         my $tapdescription = "";
+        my $D              = {};
 
         # get options
         my $ok = GetOptions (
@@ -106,8 +109,12 @@ sub run {
                              "indent=i"         => \$indent,
                              "plugins=s"        => \$plugins,
                              "verbose|v+"       => \$verbose,
+                             "fastmode"         => \$fastmode,
+                             "useforks"         => \$useforks,
                              "showconfig|c+"    => \$showconfig,
+                             "platforminfo|p"   => \$platforminfo,
                              "tapdescription=s" => \$tapdescription,
+                             "D=s%"             => \$D,
                             );
         do { usage; exit  0 } if $help;
         do { usage; exit -1 } if not $ok;
@@ -117,17 +124,19 @@ sub run {
                                        help           => $help,
                                        quiet          => $quiet,
                                        verbose        => $verbose,
+                                       fastmode       => $fastmode,
                                        showconfig     => $showconfig,
+                                       platforminfo   => $platforminfo,
                                        plugins        => $plugins,
                                        tapdescription => $tapdescription,
                                        indent         => $indent,
+                                       D              => $D,
                                       };
 
         # use forks if requested
-        my $use_forks = 0;
-        if ($ENV{PERLFORMANCE_USE_FORKS}) {
+        if ($useforks) {
                 eval "use forks";
-                $use_forks = 1 unless $@;
+                $useforks = 0 if $@;
                 print STDERR "# use forks " . ($@ ? "failed" : "") . "\n" if $verbose;
         }
 
@@ -163,16 +172,9 @@ sub run {
                 eval "\$RESULTS{results}{".join("}{", @resultkeys)."} = \$res";
         }
         my $after  = gettimeofday();
-        $RESULTS{perlformance}{overall_runtime} = $after - $before;
-
-        $RESULTS{perlformance}{config}{env} =
-        {
-         map { $_ => $ENV{$_} }
-         sort
-         grep { /^PERLFORMANCE_/ }
-         keys %ENV
-        };
-        $RESULTS{perlformance}{config}{use_forks} = $use_forks;
+        $RESULTS{perlformance}{overall_runtime}   = $after - $before;
+        $RESULTS{perlformance}{config}{fastmode}  = $fastmode;
+        $RESULTS{perlformance}{config}{use_forks} = $useforks;
 
         # Perl Config
         if ($showconfig)
@@ -185,6 +187,13 @@ sub run {
                 };
         }
 
+        # Perl Config
+        if ($platforminfo)
+        {
+                $RESULTS{platform_info} = Devel::Platform::Info->new->get_info;
+                delete $RESULTS{platform_info}{source}; # this currently breaks the simplified YAMLish
+        }
+
         unbless (\%RESULTS);
         return \%RESULTS;
 }
